@@ -38,7 +38,9 @@ typedef union {
     int widget##_x_root(const widget *self);                                                       \
     int widget##_y_root(const widget *self);                                                       \
     void widget##_set_cursor_image(widget *self, const void *image, int hot_x, int hot_y);         \
-    void widget##_default_cursor(widget *self, int cursor);
+    void widget##_default_cursor(widget *self, int cursor);                                        \
+    int widget##_screen_num(widget *);                                                             \
+    void widget##_set_screen_num(widget *, int screen_num);
 
 WIDGET_DECLARE(Fl_Window)
 
