@@ -106,8 +106,20 @@
     }                                                                                              \
     void widget##_default_cursor(widget *self, int cursor) {                                       \
         LOCK(self->default_cursor((Fl_Cursor)cursor);)                                             \
+    }                                                                                              \
+    int widget##_screen_num(widget *self) {                                                        \
+        return self->screen_num();                                                                 \
+    }                                                                                              \
+    void widget##_set_screen_num(widget *self, int screen_num) {                                   \
+        LOCK(self->screen_num(screen_num);)                                                        \
     }
 
+#ifdef __APPLE__
+int scale_factor = 2; // assume retina!
+#else
+int scale_factor = 1;
+#endif
+
 WIDGET_CLASS(Fl_Window)
 
 WIDGET_DEFINE(Fl_Window)
